==> vidtuber_1.1.6-1trisquel1.tar.xz: vidtuber-1.1.6/vidtuber/vt_sys/about_app.py <==
# -*- coding: UTF-8 -*-
"""
Name: about_app.py
Porpose: Gets information about the program
Compatibility: Python3, Python2
author: Gianluca Pernigotto <jeanlucperni@gmail.com>
Copyleft - 2025 Gianluca Pernigotto <jeanlucperni@gmail.com>
lic: GPL3
Rev: March.22.2025
Code checker: flake8, pylint

This file is part of Vidtuber.

   Vidtuber is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Vidtuber is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Vidtuber.  If not, see <http://www.gnu.org/licenses/>.
"""
PRGNAME = 'vidtuber'
RELNAME = 'Vidtuber'
VERSION = '1.1.6'
RELSTATE = 'released'
COPYRIGHT = '2023-2025'
WEBSITE = 'http://jeanslack.github.io/Vidtuber/'
AUTHOR = ('Gianluca Pernigotto', '(aka jeanslack)')
MAIL = 'jeanlucperni@gmail.com'
COMMENT = ("\nThanks to:\n"
           "- Python <https://www.python.org/>, programming language\n"
           "- wxPython <https://wxpython.org/>, cross-platform\n"
           "GUI toolkit for the Python language\n"
           "- FFmpeg, FFmpeg is a trademark of Fabrice Bellard, \n"
           "originator of the FFmpeg project:\n"
           "<http://ffmpeg.org/>\n"
           "- yt-dlp: <https://github.com/yt-dlp/yt-dlp>\n"
           "Download videos from YouTube and more sites\n"
           )
SHORTDESCRIPT = "Vidtuber is a simple cross-platform GUI for yt-dlp"
LONGDESCRIPT = """
Vidtuber is a simple, cross-platform GUI for yt-dlp written in Python3
using the wxPython4-Phoenix toolkit.
"""
SHORTLICENSE = "GPL-3.0+ (Gnu Public License)"
LICENSE = (f"Copyleft - all rights reversed - {COPYRIGHT} "
           f"{AUTHOR[0]}\n"
           f"Author and developer: {AUTHOR[0]} {AUTHOR[1]}\n"
           f"Mail: {MAIL}\n\n"
           "Vidtuber is free software: you can redistribute\n"
           "it and/or modify it under the terms of the GNU General\n"
           "Public License as published by the Free Software\n"
           "Foundation, either version 3 of the License, or (at your\n"
           "option) any later version.\n\n"

           "Vidtuber is distributed in the hope that it\n"
           "will be useful, but WITHOUT ANY WARRANTY; without\n"
           "even the implied warranty of MERCHANTABILITY or\n"
           "FITNESS FOR A PARTICULAR PURPOSE.\n"
           "See the GNU General Public License for more details.\n\n"

           "You should have received a copy of the GNU General\n"
           "Public License along with this program. If not, see\n"
           "http://www.gnu.org/licenses/"
           )

==> vidtuber_1.1.10-1trisquel1.tar.xz: vidtuber-1.1.10/vidtuber/vt_sys/about_app.py <==
# -*- coding: UTF-8 -*-
"""
Name: about_app.py
Porpose: Gets information about the program
Compatibility: Python3, Python2
author: Gianluca Pernigotto <jeanlucperni@gmail.com>
Copyleft - 2025 Gianluca Pernigotto <jeanlucperni@gmail.com>
lic: GPL3
Rev: March.22.2025
Code checker: flake8, pylint

This file is part of Vidtuber.

   Vidtuber is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Vidtuber is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Vidtuber.  If not, see <http://www.gnu.org/licenses/>.
"""
PRGNAME = 'vidtuber'
RELNAME = 'Vidtuber'
VERSION = '1.1.10'
RELSTATE = 'released'
COPYRIGHT = '2023-2025'
WEBSITE = 'http://jeanslack.github.io/Vidtuber/'
AUTHOR = ('Gianluca Pernigotto', '(aka jeanslack)')
MAIL = 'jeanlucperni@gmail.com'
COMMENT = ("\nThanks to:\n"
           "- Python <https://www.python.org/>, programming language\n"
           "- wxPython <https://wxpython.org/>, cross-platform\n"
           "GUI toolkit for the Python language\n"
           "- FFmpeg, FFmpeg is a trademark of Fabrice Bellard, \n"
           "originator of the FFmpeg project:\n"
           "<http://ffmpeg.org/>\n"
           "- yt-dlp: <https://github.com/yt-dlp/yt-dlp>\n"
           "Download videos from YouTube and more sites\n"
           )
SHORTDESCRIPT = "Vidtuber is a simple cross-platform GUI for yt-dlp"
LONGDESCRIPT = """
Vidtuber is a simple yet comprehensive, cross-platform graphical user
interface for yt-dlp written in Python3 and wxPython4-Phoenix.
"""
SHORTLICENSE = "GPL-3.0+ (Gnu Public License)"
LICENSE = (f"Copyleft - all rights reversed - {COPYRIGHT} "
           f"{AUTHOR[0]}\n"
           f"Author and developer: {AUTHOR[0]} {AUTHOR[1]}\n"
           f"Mail: {MAIL}\n\n"
           "Vidtuber is free software: you can redistribute\n"
           "it and/or modify it under the terms of the GNU General\n"
           "Public License as published by the Free Software\n"
           "Foundation, either version 3 of the License, or (at your\n"
           "option) any later version.\n\n"

           "Vidtuber is distributed in the hope that it\n"
           "will be useful, but WITHOUT ANY WARRANTY; without\n"
           "even the implied warranty of MERCHANTABILITY or\n"
           "FITNESS FOR A PARTICULAR PURPOSE.\n"
           "See the GNU General Public License for more details.\n\n"

           "You should have received a copy of the GNU General\n"
           "Public License along with this program. If not, see\n"
           "http://www.gnu.org/licenses/"
           )
